@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+
 # Copyright (c) 2009 - Luca Invernizzi <invernizzi.l@gmail.com>
 #               2012 - Izidor Matušov <izidor.matusov@gmail.com>
 #
@@ -20,23 +20,26 @@ Plugin for exporting into nice lists in TXT, HTML or PDF """
 
 import os
 import shutil
-import webbrowser
 import subprocess
+import webbrowser
 
+from gi.repository import GObject, Gtk, GdkPixbuf
 from xdg.BaseDirectory import xdg_config_home
-import gobject
-import gtk
 
-from GTG import _
+from GTG.core.translations import _
+from GTG.core.logger import log
 from GTG.plugins.export.task_str import get_task_wrappers
 from GTG.plugins.export.templates import Template, get_templates_paths
 
 
 # Enforce external dependencies
 for dependence in "pdflatex", "pdftk", "pdfjam":
-    retval = subprocess.call(["which", dependence], stdout=subprocess.PIPE)
+    retval = subprocess.call(["which", dependence],
+                             stdout=subprocess.PIPE,
+                             stderr=subprocess.DEVNULL,)
     if retval != 0:
-        raise ImportError("Missing command %s" % dependence)
+        log.debug(f'Missing command "{dependence}"')
+        raise ImportError(f'Missing command "{dependence}"')
 
 
 def get_user_dir(key):
@@ -75,7 +78,7 @@ def get_desktop_dir():
         return os.path.expanduser('~')
 
 
-class PluginExport:
+class ExportPlugin():
     """ Export plugin - handle UI and trigger exporting tasks """
 
     # Allow initilization outside __init__() and don't complain
@@ -104,7 +107,7 @@ class PluginExport:
         """ Removes the gtk widgets before quitting """
         self._gtk_deactivate()
 
-## CALLBACK AND CORE FUNCTIONS ################################################
+# CALLBACK AND CORE FUNCTIONS #################################################
     def on_export_start(self, saving):
         """ Start generating a document.
         If saving == True, ask user where to store the document. Otherwise,
@@ -132,7 +135,7 @@ class PluginExport:
         try:
             self.template.generate(tasks, self.plugin_api,
                                    self.on_export_finished)
-        except Exception, err:
+        except Exception as err:
             self.show_error_dialog(
                 _("GTG could not generate the document: %s") % err)
             raise
@@ -173,32 +176,31 @@ class PluginExport:
 
         return get_task_wrappers(tree, timespan)
 
-## GTK FUNCTIONS ##############################################################
+# GTK FUNCTIONS ###############################################################
     def _init_gtk(self):
         """ Initialize all the GTK widgets """
         self.menu_entry = False
         self.toolbar_entry = False
 
-        self.menu_item = gtk.MenuItem(_("Export the tasks currently listed"))
+        self.menu_item = Gtk.MenuItem(_("Export the tasks currently listed"))
         self.menu_item.connect('activate', self.show_dialog)
         self.menu_item.show()
 
-        self.tb_button = gtk.ToolButton(gtk.STOCK_PRINT)
+        self.tb_button = Gtk.ToolButton(Gtk.STOCK_PRINT)
         self.tb_button.connect('clicked', self.show_dialog)
         self.tb_button.show()
 
-        builder = gtk.Builder()
+        builder = Gtk.Builder()
         cur_dir = os.path.dirname(os.path.abspath(__file__))
         builder_file = os.path.join(cur_dir, "export.ui")
         builder.add_from_file(builder_file)
 
         self.combo = builder.get_object("export_combo_templ")
-        templates_list = gtk.ListStore(gobject.TYPE_STRING,
-                                       gobject.TYPE_STRING,
-                                       gobject.TYPE_STRING, gobject.TYPE_STRING
-                                       )
+        templates_list = Gtk.ListStore(
+            GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_STRING,
+            GObject.TYPE_STRING)
         self.combo.set_model(templates_list)
-        cell = gtk.CellRendererText()
+        cell = Gtk.CellRendererText()
         self.combo.pack_start(cell, True)
         self.combo.add_attribute(cell, 'text', 1)
 
@@ -293,14 +295,14 @@ class PluginExport:
         description, image = model[active][2], model[active][3]
 
         if image:
-            pixbuf = gtk.gdk.pixbuf_new_from_file(image)
+            pixbuf = GdkPixbuf.Pixbuf.new_from_file(image)
             width, height = self.export_image.get_size_request()
             pixbuf = pixbuf.scale_simple(width, height,
-                                         gtk.gdk.INTERP_BILINEAR)
+                                         GdkPixbuf.InterpType.BILINEAR)
             self.export_image.set_from_pixbuf(pixbuf)
         else:
             self.export_image.clear()
-        self.description_label.set_markup("<i>%s</i>" % description)
+        self.description_label.set_markup(f"<i>{description}</i>")
 
         # Remember the last selected path
         self.preferences["last_template"] = model[active][0]
@@ -308,35 +310,35 @@ class PluginExport:
 
     def show_error_dialog(self, message):
         """ Display an error """
-        dialog = gtk.MessageDialog(
+        dialog = Gtk.MessageDialog(
             parent=self.export_dialog,
-            flags=gtk.DIALOG_DESTROY_WITH_PARENT,
-            type=gtk.MESSAGE_ERROR,
-            buttons=gtk.BUTTONS_OK,
+            flags=Gtk.DialogFlags.DESTROY_WITH_PARENT,
+            type=Gtk.MessageType.ERROR,
+            buttons=Gtk.ButtonsType.OK,
             message_format=message)
         dialog.run()
         dialog.destroy()
 
     def choose_file(self):
         """ Let user choose a file to save and return its path """
-        chooser = gtk.FileChooserDialog(
+        chooser = Gtk.FileChooserDialog(
             title=_("Choose where to save your list"),
             parent=self.export_dialog,
-            action=gtk.FILE_CHOOSER_ACTION_SAVE,
-            buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                     gtk.STOCK_SAVE, gtk.RESPONSE_OK))
+            action=Gtk.FileChooserAction.SAVE,
+            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                     Gtk.STOCK_SAVE, Gtk.ResponseType.OK))
         chooser.set_do_overwrite_confirmation(True)
-        chooser.set_default_response(gtk.RESPONSE_OK)
+        chooser.set_default_response(Gtk.ResponseType.OK)
         chooser.set_current_folder(get_desktop_dir())
         response = chooser.run()
         filename = chooser.get_filename()
         chooser.destroy()
-        if response == gtk.RESPONSE_OK:
+        if response == Gtk.ResponseType.OK:
             return filename
         else:
             return None
 
-## Preferences methods ########################################################
+# Preferences methods #########################################################
     @classmethod
     def is_configurable(cls):
         """A configurable plugin should have this method and return True"""
