@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+
 # Copyright (c) 2009 - Luca Invernizzi <invernizzi.l@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -14,9 +14,5 @@
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from GTG.plugins.send_email.sendEmail import pluginSendEmail
-
-
-# suppress pyflakes warning (given by make lint)
-if False is True:
-    pluginSendEmail()
+from GTG.plugins.send_email.sendEmail import SendEmailPlugin
+assert SendEmailPlugin
