@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -27,22 +26,22 @@ import sys
 import uuid
 import os.path
 
-from GTG.tools.logger import Log
-from GTG.tools.borg import Borg
-from GTG.backends.genericbackend import GenericBackend
+from GTG.core.logger import log
+from GTG.core.borg import Borg
+from GTG.backends.generic_backend import GenericBackend
 from GTG.core import firstrun_tasks
-from GTG.tools import cleanxml
-from GTG.core import CoreConfig
+from GTG.core.dirs import PROJECTS_XMLFILE
+from GTG.core import cleanxml
 
 
 class BackendFactory(Borg):
-    '''
+    """
     This class holds the information about the backend types.
     Since it's about types, all information is static. The instantiated
     backends are handled in the Datastore.
     It is a Borg for what matters its only state (_backend_modules),
     since it makes no sense of keeping multiple instances of this.
-    '''
+    """
 
     BACKEND_PREFIX = "backend_"
 
@@ -50,61 +49,65 @@ class BackendFactory(Borg):
         """
          Creates a dictionary of the currently available backend modules
         """
-        super(BackendFactory, self).__init__()
+        super().__init__()
         if hasattr(self, "backend_modules"):
             # This object has already been constructed
             return
         self.backend_modules = {}
-        # Look for backends in the GTG/backends dir
-        this_dir = os.path.dirname(__file__)
-        backend_files = filter(lambda f: f.endswith(".py") and
-                               f.startswith(self.BACKEND_PREFIX),
-                               os.listdir(this_dir))
+        backend_files = self._find_backend_files()
         # Create module names
-        module_names = map(lambda f: f.replace(".py", ""), backend_files)
-        Log.debug("Backends found: " + str(module_names))
+        module_names = [f.replace(".py", "") for f in backend_files]
+        log.debug("Backends found: " + str(module_names))
         # Load backend modules
         for module_name in module_names:
             extended_module_name = "GTG.backends." + module_name
             try:
                 __import__(extended_module_name)
-            except ImportError, exception:
+            except ImportError as exception:
                 # Something is wrong with this backend, skipping
-                Log.warning("Backend %s could not be loaded: %s" %
-                           (module_name, str(exception)))
+                log.warning("Backend %s could not be loaded: %s" %
+                            (module_name, str(exception)))
                 continue
-            except Exception, exception:
+            except Exception as exception:
                 # Other exception log as errors
-                Log.error("Malformated backend %s: %s" %
-                         (module_name, str(exception)))
+                log.error(f"Malformated backend {module_name}: {str(exception)}")
                 continue
 
             self.backend_modules[module_name] = \
                 sys.modules[extended_module_name]
 
+    def _find_backend_files(self):
+        # Look for backends in the GTG/backends dir
+        this_dir = os.path.dirname(__file__)
+        for filename in os.listdir(this_dir):
+            is_python = filename.endswith(".py")
+            has_prefix = filename.startswith(self.BACKEND_PREFIX)
+            if is_python and has_prefix:
+                yield filename
+
     def get_backend(self, backend_name):
-        '''
+        """
         Returns the backend module for the backend matching
         backend_name. Else, returns none
-        '''
+        """
         if backend_name in self.backend_modules:
             return self.backend_modules[backend_name]
         else:
-            Log.debug("Trying to load backend %s, but failed!" % backend_name)
+            log.debug(f"Trying to load backend {backend_name}, but failed!")
             return None
 
     def get_all_backends(self):
-        '''
+        """
         Returns a dictionary containing all the backends types
-        '''
+        """
         return self.backend_modules
 
     def get_new_backend_dict(self, backend_name, additional_parameters={}):
-        '''
+        """
         Constructs a new backend initialization dictionary. In more
         exact terms, creates a dictionary, containing all the necessary
         entries to initialize a backend.
-        '''
+        """
         if backend_name not in self.backend_modules:
             return None
         dic = {}
@@ -113,17 +116,17 @@ class BackendFactory(Borg):
         # type
         parameters = module.Backend.get_static_parameters()
         # we all the parameters and their default values in dic
-        for param_name, param_dic in parameters.iteritems():
+        for param_name, param_dic in parameters.items():
             dic[param_name] = param_dic[GenericBackend.PARAM_DEFAULT_VALUE]
         dic["pid"] = str(uuid.uuid4())
         dic["module"] = module.Backend.get_name()
-        for param_name, param_value in additional_parameters.iteritems():
+        for param_name, param_value in additional_parameters.items():
             dic[param_name] = param_value
         dic["backend"] = module.Backend(dic)
         return dic
 
     def restore_backend_from_xml(self, dic):
-        '''
+        """
         Function restoring a backend from its xml description.
         dic should be a dictionary containing at least the key
             - "module", with the module name
@@ -131,14 +134,12 @@ class BackendFactory(Borg):
         Every other key is passed as-is to the backend, as parameter.
 
         Returns the backend instance, or None is something goes wrong
-        '''
-        if not "module" in dic or not "xmlobject" in dic:
-            Log.debug("Malformed backend configuration found! %s" %
-                      dic)
+        """
+        if "module" not in dic or "xmlobject" not in dic:
+            log.debug(f"Malformed backend configuration found! {dic}")
         module = self.get_backend(dic["module"])
         if module is None:
-            Log.debug("could not load module for backend %s" %
-                      dic["module"])
+            log.debug(f"could not load module for backend {dic['module']}")
             return None
         # we pop the xml object, as it will be redundant when the parameters
         # are set directly in the dict
@@ -146,7 +147,7 @@ class BackendFactory(Borg):
         # Building the dictionary
         parameters_specs = module.Backend.get_static_parameters()
         dic["pid"] = str(xp.getAttribute("pid"))
-        for param_name, param_dic in parameters_specs.iteritems():
+        for param_name, param_dic in parameters_specs.items():
             if xp.hasAttribute(param_name):
                 # we need to convert the parameter to the right format.
                 # we fetch the format from the static_parameters
@@ -182,17 +183,15 @@ class BackendFactory(Borg):
         return backends_dic
 
     def _read_backend_configuration_file(self):
-        '''
+        """
         Reads the file describing the current backend configuration
         (project.xml) and returns a list of dictionaries, each containing:
          - the xml object defining the backend characteristics under
               "xmlobject"
          - the name of the backend under "module"
-        '''
+        """
         # Read configuration file, if it does not exist, create one
-        datafile = os.path.join(CoreConfig().get_data_dir(),
-                                CoreConfig.DATA_FILE)
-        doc, configxml = cleanxml.openxmlfile(datafile, "config")
+        doc, configxml = cleanxml.openxmlfile(PROJECTS_XMLFILE, "config")
         xmlproject = doc.getElementsByTagName("backend")
         # collect configured backends
         return [{"xmlobject": xp,
