@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -21,9 +20,9 @@
 
 Tasks should serve as a quick tutorial how GTG works """
 
-from GTG import _
-from GTG.tools import cleanxml
-from GTG.tools.tags import extract_tags_from_text
+from GTG.core.translations import _
+from GTG.core import cleanxml
+from GTG.core.tag import extract_tags_from_text
 
 
 def populate():
