@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Getting Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -18,16 +17,16 @@
 # -----------------------------------------------------------------------------
 import imp
 import os
-import types
+import configparser
 
-from configobj import ConfigObj
 import dbus
 
-from GTG.tools.borg import Borg
-from GTG.tools.logger import Log
+from GTG.core.dirs import PLUGIN_DIRS
+from GTG.core.borg import Borg
+from GTG.core.logger import log
 
 
-class Plugin(object):
+class Plugin():
     """A class to represent a plugin."""
 
     # A reference to an instance of the plugin class
@@ -41,29 +40,34 @@ class Plugin(object):
     missing_modules = []
     missing_dbus = []
 
-    def __init__(self, info, module_path):
-        """Initialize the Plugin using a ConfigObj."""
+    def __init__(self, info, module_paths):
+        """Initialize the Plugin using a ConfigParser."""
         info_fields = {
-          'module_name': 'Module',
-          'full_name': 'Name',
-          'version': 'Version',
-          'authors': 'Authors',
-          'short_description': 'Short-description',
-          'description': 'Description',
-          'module_depends': 'Dependencies',
-          'dbus_depends': 'Dbus-dependencies',
+            'module_name': 'module',
+            'full_name': 'name',
+            'version': 'version',
+            'authors': 'authors',
+            'short_description': 'short-description',
+            'description': 'description',
+            'module_depends': 'dependencies',
+            'dbus_depends': 'dbus-dependencies',
         }
-        for attr, field in info_fields.iteritems():
+        for attr, field in info_fields.items():
             try:
                 setattr(self, attr, info[field])
             except KeyError:
                 setattr(self, attr, [])
         # turn the enabled attribute into a bool
-        self.enabled = eval(info['Enabled'])
+        self.enabled = info['enabled'].lower() == "true"
+        # ensure the module dependencies are a list
+        if isinstance(self.module_depends, str):
+            self.module_depends = self.module_depends.split(',')
+            if not self.module_depends[-1]:
+                self.module_depends = self.module_depends[:-1]
         # ensure the dbus dependencies are a list
         if isinstance(self.dbus_depends, str):
             self.dbus_depends = [self.dbus_depends]
-        self._load_module(module_path)
+        self._load_module(module_paths)
         self._check_dbus_depends()
 
     # 'active' property
@@ -87,7 +91,7 @@ class Plugin(object):
                 bus, obj_path = dbobj.split(':')
                 try:
                     dbus.SessionBus().get_object(bus, obj_path)
-                except Exception, e:
+                except Exception:
                     self.missing_dbus.append(dbobj.split(':'))
                     self.error = True
             else:
@@ -107,22 +111,22 @@ class Plugin(object):
 
     def is_configurable(self):
         """Since some plugins don't have a is_configurable() method."""
-        return self.instance and hasattr(self.instance, 'is_configurable') and (
-          self.instance.is_configurable())
+        return self.instance and hasattr(self.instance, 'is_configurable') and\
+            self.instance.is_configurable()
 
-    def _load_module(self, module_path):
+    def _load_module(self, module_paths):
         """Load the module containing this plugin."""
         try:
             # import the module containing the plugin
-            f, pathname, desc = imp.find_module(self.module_name, module_path)
+            f, pathname, desc = imp.find_module(self.module_name, module_paths)
             module = imp.load_module(self.module_name, f, pathname, desc)
             # find the class object for the actual plugin
-            for key, item in module.__dict__.iteritems():
-                if isinstance(item, types.ClassType):
+            for key, item in module.__dict__.items():
+                if isinstance(item, type):
                     self.plugin_class = item
                     self.class_name = item.__dict__['__module__'].split('.')[1]
                     break
-        except ImportError, e:
+        except ImportError as e:
             # load_module() failed, probably because of a module dependency
             if len(self.module_depends) > 0:
                 self._check_module_depends()
@@ -130,14 +134,14 @@ class Plugin(object):
                 # no dependencies in info file; use the ImportError instead
                 self.missing_modules.append(str(e).split(" ")[3])
             self.error = True
-        except Exception, e:
+        except Exception as e:
             # load_module() failed for some other reason
-            Log.error(e)
+            log.error(e)
             self.error = True
 
-    def reload(self, module_path):
+    def reload(self, module_paths):
         if not self.active:
-            self._load_module(module_path)
+            self._load_module(module_paths)
             self._check_dbus_depends()
 
 
@@ -146,26 +150,27 @@ class PluginEngine(Borg):
     A class to manage plugins. Only one can exist.
     """
 
-    def __init__(self, plugin_path=None):
+    def __init__(self):
         """Initialize the plugin engine.
         """
-        super(PluginEngine, self).__init__()
-        if hasattr(self, "plugin_path"):
-            #Borg has already been initialized, skip
+        super().__init__()
+        if hasattr(self, "plugins"):
+            # Borg has already been initialized, skip
             return
 
-        self.plugin_path = plugin_path
         self.initialized_plugins = []
         self.plugins = {}
         self.plugin_apis = []
 
         # find all plugin info files (*.gtg-plugin)
-        for path in self.plugin_path:
+        for path in PLUGIN_DIRS:
             for f in os.listdir(path):
                 info_file = os.path.join(path, f)
                 if os.path.isfile(info_file) and f.endswith('.gtg-plugin'):
-                    info = ConfigObj(info_file)
-                    p = Plugin(info["GTG Plugin"], self.plugin_path)
+                    info = configparser.ConfigParser()
+                    info.read(info_file)
+                    info = dict(info.items("GTG Plugin", True))
+                    p = Plugin(info, PLUGIN_DIRS)
                     self.plugins[p.module_name] = p
 
     def get_plugin(self, module_name):
@@ -181,19 +186,19 @@ class PluginEngine(Borg):
                                        "disabled",
                                        "all"
         """
-        all_plugins = self.plugins.itervalues()
+        all_plugins = iter(self.plugins.values())
         if kind_of_plugins == "all":
             return all_plugins
 
         def filter_fun(plugin):
-            return (kind_of_plugins == "active"   and plugin.active) or \
-                   (kind_of_plugins == "inactive" and not plugin.active) or \
-                   (kind_of_plugins == "enabled"  and plugin.enabled) or \
-                   (kind_of_plugins == "disabled" and not plugin.enabled)
-        return filter(filter_fun, all_plugins)
+            return ((kind_of_plugins == "active" and plugin.active) or
+                    (kind_of_plugins == "inactive" and not plugin.active) or
+                    (kind_of_plugins == "enabled" and plugin.enabled) or
+                    (kind_of_plugins == "disabled" and not plugin.enabled))
+        return list(filter(filter_fun, all_plugins))
 
     def register_api(self, api):
-        '''Adds a plugin api to the list of currently loaded apis'''
+        """Adds a plugin api to the list of currently loaded apis"""
         self.plugin_apis.append(api)
 
     def remove_api(self, api):
@@ -231,6 +236,8 @@ class PluginEngine(Borg):
                 for api in self.plugin_apis:
                     if hasattr(plugin.instance, "deactivate"):
                         plugin.instance.deactivate(api)
+                        classname = plugin.instance.deactivate.__class__
+                        api.remove_active_selection_changed_callback(classname)
                     if api.is_editor():
                         if hasattr(plugin.instance, "onTaskClosed"):
                             plugin.instance.onTaskClosed(api)
@@ -257,8 +264,7 @@ class PluginEngine(Borg):
             if hasattr(plugin.instance, 'onTaskClosed'):
                 plugin.instance.onTaskClosed(plugin_api)
 
-#FIXME: What are these for? must check someday! (invernizzi)
-
+# FIXME: What are these for? must check someday! (invernizzi)
     def recheck_plugins(self, plugin_apis):
         """Check plugins to make sure their states are consistent.
 
@@ -268,8 +274,8 @@ class PluginEngine(Borg):
             try:
                 if plugin.instance and plugin.enabled and plugin.active:
                     self.deactivate_plugins(self.plugin_apis, [plugin])
-                elif plugin.instance is None and plugin.enabled and (not
-                  plugin.active):
+                elif plugin.instance is None and plugin.enabled and \
+                        (not plugin.active):
                     if plugin.error:
                         plugin.enabled = False
                     else:
@@ -279,11 +285,11 @@ class PluginEngine(Borg):
                         plugin.enabled = False
                     else:
                         self.activate_plguins(self.plugin_apis, [plugin])
-            except Exception, e:
-                print "Error: %s" % e
+            except Exception as e:
+                print(f"Error: {e}")
 
     def recheck_plugin_errors(self, check_all=False):
         """Attempt a reload of plugins with errors, or all plugins."""
         for plugin in self.get_plugins():
             if check_all or plugin.error:
-                plugin.reload(self.plugin_path)
+                plugin.reload(PLUGIN_DIRS)
