@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -19,16 +18,15 @@
 
 from datetime import datetime
 
-from GTG import _
-from liblarch import Tree
-from GTG.core.task import Task
-from GTG.core.tag import Tag
-from GTG.core import CoreConfig
 from GTG.core.search import search_filter
-from GTG.tools.dates import Date
+from GTG.core import tag
+from GTG.core.task import Task
+from GTG.core.translations import _
+from GTG.core.dates import Date
+from liblarch import Tree
 
 
-class TreeFactory:
+class TreeFactory():
 
     def __init__(self):
         # Keep the tree in memory jus in case we have to use it for filters.
@@ -36,10 +34,10 @@ class TreeFactory:
         self.tagtree = None
 
     def get_tasks_tree(self):
-        '''This create a liblarch tree suitable for tasks,
+        """This create a liblarch tree suitable for tasks,
         including default filters
         For tags, filter are dynamically created at Tag insertion.
-        '''
+        """
         tasktree = Tree()
         f_dic = {
             'workview': [self.workview],
@@ -66,54 +64,52 @@ class TreeFactory:
         return tasktree
 
     def get_tags_tree(self, req):
-        '''This create a liblarch tree suitable for tags,
+        """This create a liblarch tree suitable for tags,
         including the all_tags_tag and notag_tag.
-        '''
+        """
         tagtree = Tree()
 
-        ### building the initial tags
         # Build the "all tasks tag"
-        alltag = Tag(CoreConfig.ALLTASKS_TAG, req=req)
+        alltag = tag.Tag(tag.ALLTASKS_TAG, req=req)
         alltag.set_attribute("special", "all")
-        alltag.set_attribute("label", "<span weight='bold'>%s</span>"
+        alltag.set_attribute("label", "%s"
                              % _("All tasks"))
-        alltag.set_attribute("icon", "gtg-tags-all")
+        alltag.set_attribute("icon", "emblem-documents-symbolic")
         alltag.set_attribute("order", 0)
         tagtree.add_node(alltag)
         p = {}
-        self.tasktree.add_filter(CoreConfig.ALLTASKS_TAG,
+        self.tasktree.add_filter(tag.ALLTASKS_TAG,
                                  self.alltag, parameters=p)
         # Build the "without tag tag"
-        notag_tag = Tag(CoreConfig.NOTAG_TAG, req=req)
+        notag_tag = tag.Tag(tag.NOTAG_TAG, req=req)
         notag_tag.set_attribute("special", "notag")
-        notag_tag.set_attribute("label", "<span weight='bold'>%s</span>"
+        notag_tag.set_attribute("label", "%s"
                                 % _("Tasks with no tags"))
-        notag_tag.set_attribute("icon", "gtg-tags-none")
+        notag_tag.set_attribute("icon", "task-past-due-symbolic")
         notag_tag.set_attribute("order", 2)
         tagtree.add_node(notag_tag)
         p = {}
-        self.tasktree.add_filter(CoreConfig.NOTAG_TAG,
+        self.tasktree.add_filter(tag.NOTAG_TAG,
                                  self.notag, parameters=p)
 
         # Build the search tag
-        search_tag = Tag(CoreConfig.SEARCH_TAG, req=req)
+        search_tag = tag.Tag(tag.SEARCH_TAG, req=req)
         search_tag.set_attribute("special", "search")
-        search_tag.set_attribute("label",
-                                 "<span weight='bold'>%s</span>" % _("Search"))
-        search_tag.set_attribute("icon", "search")
+        search_tag.set_attribute("label", _("Search"))
+        search_tag.set_attribute("icon", "system-search-symbolic")
         search_tag.set_attribute("order", 1)
         tagtree.add_node(search_tag)
         p = {}
-        self.tasktree.add_filter(CoreConfig.SEARCH_TAG,
+        self.tasktree.add_filter(tag.SEARCH_TAG,
                                  search_filter, parameters=p)
 
         # Build the separator
-        sep_tag = Tag(CoreConfig.SEP_TAG, req=req)
+        sep_tag = tag.Tag(tag.SEP_TAG, req=req)
         sep_tag.set_attribute("special", "sep")
         sep_tag.set_attribute("order", 3)
         tagtree.add_node(sep_tag)
 
-        #### Filters
+        # Filters
         tagtree.add_filter('activetag', self.actively_used_tag)
         tagtree.add_filter('usedtag', self.used_tag)
 
@@ -128,7 +124,7 @@ class TreeFactory:
         self.tagtree_loaded = True
         return tagtree
 
-    ################# Tag Filters ##########################################
+    # Tag Filters ##########################################
 
     # filter to display only tags with active tasks
     def actively_used_tag(self, node, parameters=None):
@@ -138,7 +134,7 @@ class TreeFactory:
     def used_tag(self, node, parameters=None):
         return node.is_used()
 
-    ################# Task Filters #########################################
+    # Task Filters #########################################
     # That one is used to filters tag. Is it built dynamically each times
     # a tag is added to the tagstore
     def tag_filter(self, node, parameters):
@@ -191,27 +187,27 @@ class TreeFactory:
         return wv
 
     def workdue(self, task):
-        ''' Filter for tasks due within the next day '''
+        """ Filter for tasks due within the next day """
         wv = (self.workview(task) and
               task.get_due_date() and
               task.get_days_left() < 2)
         return wv
 
     def worklate(self, task):
-        ''' Filter for tasks due within the next day '''
+        """ Filter for tasks due within the next day """
         wv = (self.workview(task) and
               task.get_due_date() and
               task.get_days_late() > 0)
         return wv
 
     def workstarted(self, task):
-        ''' Filter for workable tasks with a start date specified '''
+        """ Filter for workable tasks with a start date specified """
         wv = self.workview(task) and \
             task.start_date
         return wv
 
     def worktostart(self, task):
-        ''' Filter for workable tasks without a start date specified '''
+        """ Filter for workable tasks without a start date specified """
         wv = self.workview(task) and \
             not task.start_date
         return wv
