@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+
 # Copyright (c) 2010 - Luca Invernizzi <invernizzi.l@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -14,6 +14,9 @@
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from GTG import _
+""" Text only template """
+
+from GTG.core.translations import _
+
 title = _("Text-only")
 description = _("A template to create a simple text file with some tasks.")
