@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+
 # Copyright (c) 2012 - Lionel Dricot <lionel@ploum.net>
 
 # This program is free software: you can redistribute it and/or modify it under
@@ -14,10 +14,5 @@
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 
-""" Not today pluging"""
-
-from GTG.plugins.not_today.not_today import notToday
-
-# suppress pyflakes warning (given by make lint)
-if False:
-    notToday()
+from GTG.plugins.not_today.not_today import NotTodayPlugin
+assert NotTodayPlugin
