@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -18,28 +17,24 @@
 # -----------------------------------------------------------------------------
 
 
-#This is the tool package. It contains some useful function and tool
-#that could be useful for any part of GTG.
+# This is the tool package. It contains some useful function and tool
+# that could be useful for any part of GTG.
 
-import os
+from GTG.core.translations import _
 
-from GTG import _
 
-class GnomeConfig:
-    current_rep = os.path.dirname(os.path.abspath(__file__))
-    GLADE_FILE    = os.path.join(current_rep,"pluginmanager.glade")
-    
+class GnomeConfig():
     CANLOAD = _("Everything necessary to run this plugin is available.")
     CANNOTLOAD = _("The plugin can not be loaded")
     miss1 = _("Some python modules are missing")
     miss2 = _("Please install the following python modules:")
-    MODULEMISSING = "%s \n%s" %(miss1,miss2)
+    MODULEMISSING = f"{miss1} \n{miss2}"
     dmiss1 = _("Some remote dbus objects are missing.")
     dmiss2 = _("Please start the following applications:")
-    DBUSMISSING = "%s \n%s" %(dmiss1,dmiss2)
+    DBUSMISSING = f"{dmiss1} \n{dmiss2}"
     bmiss1 = _("Some modules and remote dbus objects are missing.")
     bmiss2 = _("Please install or start the following components:")
-    MODULANDDBUS = "%s \n%s" %(bmiss1,bmiss2)
+    MODULANDDBUS = f"{bmiss1} \n{bmiss2}"
     umiss1 = _("Unknown error while loading the plugin.")
     umiss2 = _("Very helpful message, isn't it? Please report a bug.")
-    UNKNOWN = "%s \n%s" %(umiss1,umiss2)
+    UNKNOWN = f"{umiss1} \n{umiss2}"
