@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
 # Getting Things GNOME! - a personal organizer for the GNOME desktop
 # Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
@@ -27,48 +26,46 @@ TagIconSelector is intended as a floating window that allows to select an icon
 for a tag.
 """
 
-import pygtk
-pygtk.require('2.0')
-import gobject
-import gtk
-import gtk.gdk as gdk
+from gi.repository import GObject, Gtk, Gdk, GdkPixbuf
 
-from GTG import _
-from GTG.tools.logger import Log
+from GTG.core.translations import _
 from GTG.gtk.browser.simple_color_selector import SimpleColorSelector
+from GTG.gtk.colors import color_add, color_remove
+from GTG.core.logger import log
 
 
-class TagIconSelector(gtk.Window):
+class TagIconSelector(Gtk.Window):
     """
     TagIconSelector is intended as a floating window that allows to select
     an icon for a tag. It display a list of icon in a popup window.
     """
 
     def __init__(self):
-        self.__gobject_init__(type=gtk.WINDOW_POPUP)
-        gtk.Window.__init__(self)
+        super().__init__()
         self.loaded = False
         self.selected_icon = None
         self.symbol_model = None
         # Build up the window
         self.__build_window()
         # Make it visible
-        self.hide_all()
+        # self.hide_all()
+        # FIXME
+        self.hide()
 
     def __build_window(self):
         """Build up the widget"""
-        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_POPUP_MENU)
-        vbox = gtk.VBox()
+        self.set_type_hint(Gdk.WindowTypeHint.POPUP_MENU)
+        vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         self.add(vbox)
         # icon list
-        scld_win = gtk.ScrolledWindow()
-        scld_win.set_policy(gtk.POLICY_NEVER, gtk.POLICY_ALWAYS)
-        scld_win.set_shadow_type(gtk.SHADOW_ETCHED_IN)
-        vbox.pack_start(scld_win, expand=True, fill=True)
-        self.symbol_iv = gtk.IconView()
+        scld_win = Gtk.ScrolledWindow()
+        scld_win.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.ALWAYS)
+        scld_win.set_shadow_type(Gtk.ShadowType.ETCHED_IN)
+        vbox.pack_start(scld_win, True, True, 0)
+        self.symbol_iv = Gtk.IconView()
         self.symbol_iv.set_pixbuf_column(0)
-        self.symbol_iv.set_property("columns", 7)
-        self.symbol_iv.set_property("item-width", 32)
+        self.symbol_iv.set_columns(7)
+        self.symbol_iv.set_item_width(32)
         # IconView size:
         # --------------
         #  it seems that with the above parameters, a row width is about:
@@ -77,25 +74,24 @@ class TagIconSelector(gtk.Window):
         #  The same goes for row height, but being right for this value is less
         #  important due to the vertical scrollbar.
         #  The IcVw size should fit the width of 7 cols and height of ~4 lines.
-        self.symbol_iv.set_size_request(40 * 7 + 12, 38 * 4)
+        SIZE_REQUEST = (40 * 7 + 12, 38 * 4)
+        self.symbol_iv.set_size_request(*SIZE_REQUEST)
+        scld_win.set_size_request(*SIZE_REQUEST)
         scld_win.add(self.symbol_iv)
         # icon remove button
-        img = gtk.Image()
-        img.set_from_stock(gtk.STOCK_REMOVE, gtk.ICON_SIZE_BUTTON)
-        self.remove_bt = gtk.Button()
-        self.remove_bt.set_image(img)
+        self.remove_bt = Gtk.Button()
         self.remove_bt.set_label(_("Remove selected icon"))
-        vbox.pack_start(self.remove_bt, fill=False, expand=False)
+        vbox.pack_start(self.remove_bt, False, False, 0)
         # set the callbacks
         self.symbol_iv.connect("selection-changed", self.on_selection_changed)
         self.remove_bt.connect("clicked", self.on_remove_bt_clicked)
 
     def __focus_out(self, widget, event):
         """Hides the window if the user clicks out of it"""
-        win_ptr = self.window.get_pointer()
+        win_ptr = self.get_window().get_pointer()
         win_size = self.get_size()
-        if not(0 <= win_ptr[0] <= win_size[0] and
-               0 <= win_ptr[1] <= win_size[1]):
+        if not(0 <= win_ptr[1] <= win_size[0] and
+               0 <= win_ptr[2] <= win_size[1]):
             self.close_selector()
 
     def __load_icon(self):
@@ -106,22 +102,22 @@ class TagIconSelector(gtk.Window):
         libraries, e.g. bug #1079587. Gracefuly degradate and skip
         the loading of a corrupted icon.
         """
-        self.symbol_model = gtk.ListStore(gtk.gdk.Pixbuf, str)
-        for icon in gtk.icon_theme_get_default().list_icons(context="Emblems"):
+        self.symbol_model = Gtk.ListStore(GdkPixbuf.Pixbuf, str)
+        for icon in Gtk.IconTheme.get_default().list_icons(context="Emblems"):
             try:
-                img = gtk.icon_theme_get_default().load_icon(icon, 16, 0)
+                img = Gtk.IconTheme.get_default().load_icon(icon, 16, 0)
                 self.symbol_model.append([img, icon])
-            except gobject.GError:
-                Log.error("Failed to load icon '%s'" % icon)
+            except GObject.GError:
+                log.error(f"Failed to load icon '{icon}'")
         self.symbol_iv.set_model(self.symbol_model)
         self.loaded = True
 
-    ### PUBLIC IF ###
+    # PUBLIC IF #####
     def set_remove_enabled(self, enable):
         """Disable/enable the remove button"""
         self.remove_bt.set_sensitive(enable)
 
-    ### callbacks ###
+    # callbacks #####
     def on_selection_changed(self, widget):
         """Callback: update the model according to the selected icon. Also
         notifies the parent widget."""
@@ -140,7 +136,7 @@ class TagIconSelector(gtk.Window):
         self.emit('selection-changed')
         self.close_selector()
 
-    ### PUBLIC IF ###
+    # PUBLIC IF #####
     def show_at_position(self, pos_x, pos_y):
         """Displays the window at a specific point on the screen"""
         if not self.loaded:
@@ -152,14 +148,22 @@ class TagIconSelector(gtk.Window):
         self.move(pos_x, pos_y)
         self.grab_add()
         # We grab the pointer in the calendar
-        gdk.pointer_grab(self.window, True,
-                         gdk.BUTTON1_MASK | gdk.MOD2_MASK)
+        # FIXME THIS DOES NOT WORK!!!!!!!
+        Gdk.pointer_grab(self.get_window(), True,
+                         # Gdk.ModifierType.BUTTON1_MASK |
+                         # Gdk.ModifierType.MOD2_MASK,
+                         # FIXME!!!! JUST GUESSING THE TYPE
+                         Gdk.EventMask.ALL_EVENTS_MASK,
+                         None,
+                         None,
+                         0,)
         self.connect('button-press-event', self.__focus_out)
 
     def close_selector(self):
         """Hides the window"""
         self.hide()
-        gtk.gdk.pointer_ungrab()
+        # FIXME!!!
+        Gdk.pointer_ungrab(0)
         self.grab_remove()
 
     def get_selected_icon(self):
@@ -171,19 +175,19 @@ class TagIconSelector(gtk.Window):
         self.symbol_iv.unselect_all()
 
 
-gobject.type_register(TagIconSelector)
-gobject.signal_new("selection-changed", TagIconSelector,
-                   gobject.SIGNAL_RUN_FIRST, gobject.TYPE_NONE, ())
+GObject.type_register(TagIconSelector)
+GObject.signal_new("selection-changed", TagIconSelector,
+                   GObject.SignalFlags.RUN_FIRST, None, ())
 
 
-class TagEditor(gtk.Window):
+class TagEditor(Gtk.Window):
     """Window allowing to edit a tag's properties."""
 
-    def __init__(self, req, vmanager, tag=None):
-        gtk.Window.__init__(self)
-        self.__gobject_init__()
+    def __init__(self, req, app, tag=None):
+        super().__init__()
+
         self.req = req
-        self.vmanager = vmanager
+        self.app = app
         self.tag = tag
         self.config = self.req.get_config('tag_editor')
         self.custom_colors = None
@@ -193,7 +197,7 @@ class TagEditor(gtk.Window):
         self.tis_selection_changed_hid = None
         self.tag_icon_selector = None
         # Build up the window
-        self.set_position(gtk.WIN_POS_CENTER)
+        self.set_position(Gtk.WindowPosition.CENTER)
         self.set_title('Edit tag')
         self.set_border_width(10)
         self.set_resizable(False)
@@ -206,57 +210,59 @@ class TagEditor(gtk.Window):
     def __build_window(self):
         """Build up the widget"""
         # toplevel widget
-        self.top_vbox = gtk.VBox()
+        self.top_vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
         self.add(self.top_vbox)
-        # header line: icon, table with name and "hide in wv"
-        self.hdr_align = gtk.Alignment()
-        self.top_vbox.pack_start(self.hdr_align)
+        # header line: icon, grid with name and "hide in wv"
+        # FIXME
+        self.hdr_align = Gtk.Alignment()
+        self.top_vbox.pack_start(self.hdr_align, True, True, 0)
         self.hdr_align.set_padding(0, 25, 0, 0)
-        self.hdr_hbox = gtk.HBox()
-        self.hdr_align.add(self.hdr_hbox)
-        self.hdr_hbox.set_spacing(10)
+        self.hdr_box = Gtk.Box()
+        self.hdr_align.add(self.hdr_box)
+        self.hdr_box.set_spacing(10)
         # Button to tag icon selector
-        self.ti_bt = gtk.Button()
-        self.ti_bt_label = gtk.Label()
+        self.ti_bt = Gtk.Button()
+        self.ti_bt_label = Gtk.Label()
         self.ti_bt.add(self.ti_bt_label)
-        self.hdr_hbox.pack_start(self.ti_bt)
+        self.hdr_box.pack_start(self.ti_bt, True, True, 0)
         self.ti_bt.set_size_request(64, 64)
-        self.ti_bt.set_relief(gtk.RELIEF_HALF)
+        self.ti_bt.set_relief(Gtk.ReliefStyle.HALF)
         # vbox for tag name and hid in WV
-        self.tp_table = gtk.Table(2, 2)
-        self.hdr_hbox.pack_start(self.tp_table)
-        self.tp_table.set_col_spacing(0, 5)
-        self.tn_entry_lbl_align = gtk.Alignment(0, 0.5)
-        self.tp_table.attach(self.tn_entry_lbl_align, 0, 1, 0, 1)
-        self.tn_entry_lbl = gtk.Label()
+        self.tp_grid = Gtk.Grid()
+        self.hdr_box.pack_start(self.tp_grid, True, True, 0)
+        self.tp_grid.set_column_spacing(5)
+        self.tn_entry_lbl_align = Gtk.Alignment.new(0, 0.5, 0, 0)
+        self.tp_grid.add(self.tn_entry_lbl_align)
+        self.tn_entry_lbl = Gtk.Label()
         self.tn_entry_lbl.set_markup("<span weight='bold'>%s</span>"
                                      % _("Name : "))
         self.tn_entry_lbl_align.add(self.tn_entry_lbl)
-        self.tn_entry = gtk.Entry()
-        self.tp_table.attach(self.tn_entry, 1, 2, 0, 1)
+        self.tn_entry = Gtk.Entry()
         self.tn_entry.set_width_chars(20)
-        self.tn_cb_lbl_align = gtk.Alignment(0, 0.5)
-        self.tp_table.attach(self.tn_cb_lbl_align, 0, 1, 1, 2)
-        self.tn_cb_lbl = gtk.Label(_("Show Tag in Work View :"))
+        self.tp_grid.attach(self.tn_entry, 1, 0, 1, 1)
+        self.tn_cb_lbl_align = Gtk.Alignment.new(0, 0.5, 0, 0)
+        self.tp_grid.attach(self.tn_cb_lbl_align, 0, 1, 1, 1)
+        self.tn_cb_lbl = Gtk.Label(label=_("Show Tag in Work View :"))
         self.tn_cb_lbl_align.add(self.tn_cb_lbl)
-        self.tn_cb = gtk.CheckButton()
-        self.tp_table.attach(self.tn_cb, 1, 2, 1, 2)
+        self.tn_cb = Gtk.CheckButton()
+        self.tp_grid.attach(self.tn_cb, 1, 1, 1, 1)
         # Tag color
-        self.tc_vbox = gtk.VBox()
-        self.top_vbox.pack_start(self.tc_vbox)
-        self.tc_label_align = gtk.Alignment()
-        self.tc_vbox.pack_start(self.tc_label_align)
+        self.tc_vbox = Gtk.Box(orientation=Gtk.Orientation.VERTICAL)
+        self.top_vbox.pack_start(self.tc_vbox, True, True, 0)
+        self.tc_label_align = Gtk.Alignment()
+        self.tc_vbox.pack_start(self.tc_label_align, True, True, 0)
         self.tc_label_align.set_padding(0, 0, 0, 0)
-        self.tc_label = gtk.Label()
+        self.tc_label = Gtk.Label()
         self.tc_label_align.add(self.tc_label)
         self.tc_label.set_markup(
             "<span weight='bold'>%s</span>" % _("Select Tag Color:"))
         self.tc_label.set_alignment(0, 0.5)
         # Tag color chooser
-        self.tc_cc_align = gtk.Alignment(0.5, 0.5, 0, 0)
-        self.tc_vbox.pack_start(self.tc_cc_align)
+        self.tc_cc_align = Gtk.Alignment.new(0.5, 0.5, 0, 0)
+        self.tc_vbox.pack_start(self.tc_cc_align, True, True, 0)
         self.tc_cc_align.set_padding(15, 15, 10, 10)
         self.tc_cc_colsel = SimpleColorSelector()
+        # self.tc_cc_colsel = Gtk.ColorChooserWidget()
         self.tc_cc_align.add(self.tc_cc_colsel)
         # Icon selector
         self.tag_icon_selector = TagIconSelector()
@@ -272,15 +278,21 @@ class TagEditor(gtk.Window):
             self.tn_entry.connect('changed', self.on_tn_entry_changed)
         self.tn_cb_clicked_hid = self.tn_cb.connect('clicked',
                                                     self.on_tn_cb_clicked)
+        # FIXME
         self.tc_cc_colsel.connect('color-changed', self.on_tc_colsel_changed)
         self.tc_cc_colsel.connect('color-added', self.on_tc_colsel_added)
+        # self.tc_cc_colsel.connect('color-activated',
+        #                           self.on_tc_colsel_activated)
         self.connect('delete-event', self.on_close)
 
         # allow fast closing by Escape key
-        agr = gtk.AccelGroup()
+        # FIXME
+        """
+        agr = Gtk.AccelGroup()
         self.add_accel_group(agr)
-        key, modifier = gtk.accelerator_parse('Escape')
-        agr.connect_group(key, modifier, gtk.ACCEL_VISIBLE, self.on_close)
+        key, modifier = Gtk.accelerator_parse('Escape')
+        agr.connect_group(key, modifier, Gtk.AccelFlags.VISIBLE, self.on_close)
+        """
 
     def __set_default_values(self):
         """Configure the widget components with their initial default values"""
@@ -291,7 +303,7 @@ class TagEditor(gtk.Window):
         self.tag_icon_selector.handler_block(self.tis_selection_changed_hid)
         # Default icon
         markup = "<span size='small'>%s</span>" % _("Click To\nSet Icon")
-        self.ti_bt_label.set_justify(gtk.JUSTIFY_CENTER)
+        self.ti_bt_label.set_justify(Gtk.Justification.CENTER)
         self.ti_bt_label.set_markup(markup)
         self.ti_bt_label.show()
         self.__set_icon(None)
@@ -301,9 +313,13 @@ class TagEditor(gtk.Window):
         self.tn_cb.set_active(True)
         # Name entry
         self.tn_entry.set_text(_("Enter tag name here"))
-        self.tn_entry.set_icon_from_stock(gtk.ENTRY_ICON_SECONDARY, None)
+        self.tn_entry.set_icon_from_icon_name(Gtk.EntryIconPosition.SECONDARY,
+                                              None)
         # Color selection
+        # FIXME
         self.tc_cc_colsel.unselect_color()
+        # self.tc_cc_colsel.set_use_alpha(False)
+        # self.tc_cc_colsel.set_rgba(self.tc_cc_colsel, None)
         # Custom colors
         self.custom_colors = self.config.get('custom_colors')
         if len(self.custom_colors) > 0:
@@ -321,8 +337,8 @@ class TagEditor(gtk.Window):
         if icon is not None:
             for i in self.ti_bt:
                 self.ti_bt.remove(i)
-            ti_bt_img = gtk.image_new_from_icon_name(icon,
-                                                     gtk.ICON_SIZE_BUTTON)
+            ti_bt_img = Gtk.Image.new_from_icon_name(icon,
+                                                     Gtk.IconSize.BUTTON)
             ti_bt_img.show()
             self.ti_bt.add(ti_bt_img)
         else:
@@ -330,7 +346,7 @@ class TagEditor(gtk.Window):
                 self.ti_bt.remove(i)
             self.ti_bt.add(self.ti_bt_label)
 
-    ### PUBLIC API ###
+    # PUBLIC API #####
     def set_tag(self, tag):
         """Update the context menu items using the tag attributes."""
         # set_active emit the 'toggle' signal, so we have to disable
@@ -367,7 +383,7 @@ class TagEditor(gtk.Window):
             self.tn_cb.handler_unblock(self.tn_cb_clicked_hid)
             self.tn_entry.handler_unblock(self.tn_entry_clicked_hid)
 
-    ### CALLBACKS ###
+    # CALLBACKS #####
     def watch_tn_entry_changes(self):
         """Monitors the value changes in the tag name entry. If no updates have
         been noticed after 1 second, request an update."""
@@ -384,7 +400,14 @@ class TagEditor(gtk.Window):
                     new_name = cur_value
                 else:
                     new_name = "@" + cur_value
+
                 self.req.rename_tag(self.tag.get_name(), new_name)
+                self.tag = self.req.get_tag(new_name)
+
+                # Select on sidebar and update values
+                self.app.browser.select_on_sidebar(new_name)
+                self.app.browser.apply_filter_on_panes(new_name)
+
             return False
 
     def on_tis_selection_changed(self, widget):
@@ -401,8 +424,11 @@ class TagEditor(gtk.Window):
         """Callback: displays the tag icon selector widget next
         to the button."""
         rect = self.ti_bt.get_allocation()
-        pos_x, pos_y = \
-            self.ti_bt.window.get_origin()
+        # print self.ti_bt.get_window().get_origin()
+        # FIXME
+        result, pos_x, pos_y = \
+            self.ti_bt.get_window().get_origin()
+        #   self.ti_bt.window.get_origin()
         self.tag_icon_selector.show_at_position(
             pos_x + rect.x + rect.width + 2,
             pos_y + rect.y)
@@ -417,17 +443,18 @@ class TagEditor(gtk.Window):
         self.tn_entry_last_recorded_value = self.tn_entry.get_text()
         # check validity
         if self.tn_entry_last_recorded_value.strip() == "":
-            self.tn_entry.set_icon_from_stock(gtk.ENTRY_ICON_SECONDARY,
-                                              gtk.STOCK_DIALOG_ERROR)
+            self.tn_entry.set_icon_from_icon_name(
+                Gtk.EntryIconPosition.SECONDARY, Gtk.STOCK_DIALOG_ERROR)
         else:
-            self.tn_entry.set_icon_from_stock(gtk.ENTRY_ICON_SECONDARY, None)
+            self.tn_entry.set_icon_from_icon_name(
+                Gtk.EntryIconPosition.SECONDARY, None)
         # filter out change requests to reduce commit overhead
         if self.tn_entry_watch_id is None:
             # There is no watchers for the text entry. Register one.
             # Also, wait 1 second before commiting the change in order to
             # reduce rename requests
             tn_entry_changes = self.watch_tn_entry_changes
-            self.tn_entry_watch_id = gobject.timeout_add(1000,
+            self.tn_entry_watch_id = GObject.timeout_add(1000,
                                                          tn_entry_changes)
 
     def on_tn_cb_clicked(self, widget):
@@ -442,6 +469,24 @@ class TagEditor(gtk.Window):
         """Callback: update the tag color depending on the current color
         selection"""
         color = self.tc_cc_colsel.get_selected_color()
+        if self.tag is not None:
+            if color is not None:
+                my_color = Gdk.color_parse(color)
+                color = Gdk.Color(
+                    my_color.red, my_color.green, my_color.blue).to_string()
+                color_add(color)
+                self.tag.set_attribute('color', color)
+            else:
+                color_remove(self.tag.get_attribute('color'))
+                self.tag.del_attribute('color')
+
+    def on_tc_colsel_activated(self, widget, color):
+        """Callback: update the tag color depending on the current color
+        selection"""
+        print("activated", widget, color, " <--- ignoring for now")
+        return
+        # color = self.tc_cc_colsel.get_rgba().to_color()
+        color = color.to_color()
         if self.tag is not None:
             if color is not None:
                 self.tag.set_attribute('color', color)
@@ -460,5 +505,5 @@ class TagEditor(gtk.Window):
         Arguments arg1-arg3 are needed to satisfy callback when closing
         by Escape
         """
-        self.vmanager.close_tag_editor()
+        self.app.close_tag_editor()
         return True
